import { PlayerJoin, ServerJoin } from './accounts';
import { Fields, Id } from './types';
type EventFields<T> = Omit<Fields<T>, 'kind'>;
export type EventKind = 'Custom' | 'Ready' | 'ShareSecrets' | 'OperationTimeout' | 'Mask' | 'Lock' | 'RandomnessReady' | 'Sync' | 'ServerLeave' | 'Leave' | 'GameStart' | 'WaitingTimeout' | 'DrawRandomItems' | 'DrawTimeout' | 'ActionTimeout' | 'AnswerDecision' | 'SecretsReady' | 'Shutdown';
export interface ICustomEvent {
    serialize(): Uint8Array;
}
interface IEventKind {
    kind(): string;
}
export declare abstract class SecretShare {
}
export declare class Random extends SecretShare {
    fromAddr: string;
    toAddr: string | undefined;
    randomId: Id;
    index: number;
    secret: Uint8Array;
    constructor(fields: EventFields<Random>);
    kind(): string;
}
export declare class Answer extends SecretShare {
    fromAddr: string;
    decisionId: Id;
    secret: Uint8Array;
    constructor(fields: EventFields<Answer>);
}
export declare abstract class GameEvent implements IEventKind {
    kind(): string;
}
export declare class Custom extends GameEvent implements IEventKind {
    sender: string;
    raw: Uint8Array;
    constructor(fields: EventFields<Custom>);
    kind(): string;
}
export declare function makeCustomEvent(sender: string, customEvent: ICustomEvent): Custom;
export declare class Ready extends GameEvent implements IEventKind {
    constructor(_?: any);
    kind(): string;
}
export declare class ShareSecrets extends GameEvent implements IEventKind {
    sender: string;
    shares: SecretShare[];
    constructor(fields: EventFields<ShareSecrets>);
    kind(): string;
}
export declare class OperationTimeout extends GameEvent implements IEventKind {
    addrs: string[];
    constructor(fields: EventFields<OperationTimeout>);
    kind(): string;
}
export declare class Mask extends GameEvent implements IEventKind {
    sender: string;
    randomId: Id;
    ciphertexts: Uint8Array[];
    constructor(fields: EventFields<Mask>);
    kind(): string;
}
export declare class CiphertextAndDigest {
    ciphertext: Uint8Array;
    digest: Uint8Array;
    constructor(fields: EventFields<CiphertextAndDigest>);
}
export declare class Lock extends GameEvent implements IEventKind {
    sender: string;
    randomId: Id;
    ciphertextsAndDigests: CiphertextAndDigest[];
    constructor(fields: EventFields<Lock>);
    kind(): string;
}
export declare class RandomnessReady extends GameEvent implements IEventKind {
    randomId: Id;
    constructor(fields: EventFields<RandomnessReady>);
    kind(): string;
}
export declare class Sync extends GameEvent implements IEventKind {
    newPlayers: PlayerJoin[];
    newServers: ServerJoin[];
    transactorAddr: string;
    accessVersion: bigint;
    constructor(fields: EventFields<Sync>);
    kind(): string;
}
export declare class ServerLeave extends GameEvent implements IEventKind {
    serverAddr: string;
    transactorAddr: string;
    constructor(fields: EventFields<ServerLeave>);
    kind(): string;
}
export declare class Leave extends GameEvent implements IEventKind {
    playerAddr: string;
    constructor(fields: EventFields<Leave>);
    kind(): string;
}
export declare class GameStart extends GameEvent implements IEventKind {
    accessVersion: bigint;
    constructor(fields: EventFields<GameStart>);
    kind(): string;
}
export declare class WaitingTimeout extends GameEvent implements IEventKind {
    constructor(_?: any);
    kind(): string;
}
export declare class DrawRandomItems extends GameEvent implements IEventKind {
    sender: string;
    randomId: Id;
    indexes: number[];
    constructor(fields: EventFields<DrawRandomItems>);
    kind(): string;
}
export declare class DrawTimeout extends GameEvent implements IEventKind {
    constructor(_: {});
    kind(): string;
}
export declare class ActionTimeout extends GameEvent implements IEventKind {
    playerAddr: string;
    constructor(fields: EventFields<ActionTimeout>);
    kind(): string;
}
export declare class AnswerDecision extends GameEvent implements IEventKind {
    sender: string;
    decisionId: Id;
    ciphertext: Uint8Array;
    digest: Uint8Array;
    constructor(fields: EventFields<AnswerDecision>);
    kind(): string;
}
export declare class SecretsReady extends GameEvent implements IEventKind {
    constructor(_?: any);
    kind(): string;
}
export declare class Shutdown extends GameEvent implements IEventKind {
    constructor(_?: any);
    kind(): string;
}
export {};
